package com.ruoyi.web.controller.system;

import java.util.Date;
import java.util.List;
import javax.servlet.ServletRequest;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.*;
import com.ruoyi.system.domain.Dangan;
import com.ruoyi.system.domain.SysConfig;
import com.ruoyi.system.domain.UserRelate;
import com.ruoyi.system.mapper.SysConfigMapper;
import com.ruoyi.system.service.IDanganService;
import com.ruoyi.system.service.IUserRelateService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.util.CollectionUtils;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.constant.ShiroConstants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysMenu;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.framework.shiro.service.SysPasswordService;
import com.ruoyi.system.service.ISysConfigService;
import com.ruoyi.system.service.ISysMenuService;

/**
 * 首页 业务处理
 * 
 * @author ruoyi
 */
@Controller
public class SysIndexController extends BaseController
{
    @Autowired
    private ISysMenuService menuService;

    @Autowired
    private ISysConfigService configService;

    @Autowired
    private SysPasswordService passwordService;

    @Autowired
    private IDanganService danganService;

    @Autowired
    private IUserRelateService userRelateService;

    @Autowired
    private SysConfigMapper configMapper;

    @Value("${ip}")
    private String ipPort;

    // 系统首页
    @GetMapping("/index")
    public String index(ModelMap mmap)
    {
        // 取身份信息
        SysUser user = getSysUser();
        // 根据用户id取出菜单
        List<SysMenu> menus = menuService.selectMenusByUser(user);
        mmap.put("menus", menus);
        mmap.put("user", user);
        mmap.put("sideTheme", configService.selectConfigByKey("sys.index.sideTheme"));
        mmap.put("skinName", configService.selectConfigByKey("sys.index.skinName"));
        Boolean footer = Convert.toBool(configService.selectConfigByKey("sys.index.footer"), true);
        Boolean tagsView = Convert.toBool(configService.selectConfigByKey("sys.index.tagsView"), true);
        mmap.put("footer", footer);
        mmap.put("tagsView", tagsView);
        mmap.put("mainClass", contentMainClass(footer, tagsView));
        mmap.put("copyrightYear", RuoYiConfig.getCopyrightYear());
        mmap.put("demoEnabled", RuoYiConfig.isDemoEnabled());
        mmap.put("isDefaultModifyPwd", initPasswordIsModify(user.getPwdUpdateDate()));
        mmap.put("isPasswordExpired", passwordIsExpiration(user.getPwdUpdateDate()));
        mmap.put("isMobile", ServletUtils.checkAgentIsMobile(ServletUtils.getRequest().getHeader("User-Agent")));

        // 菜单导航显示风格
        String menuStyle = configService.selectConfigByKey("sys.index.menuStyle");
        // 移动端，默认使左侧导航菜单，否则取默认配置
        String indexStyle = ServletUtils.checkAgentIsMobile(ServletUtils.getRequest().getHeader("User-Agent")) ? "index" : menuStyle;

        // 优先Cookie配置导航菜单
        Cookie[] cookies = ServletUtils.getRequest().getCookies();
        for (Cookie cookie : cookies)
        {
            if (StringUtils.isNotEmpty(cookie.getName()) && "nav-style".equalsIgnoreCase(cookie.getName()))
            {
                indexStyle = cookie.getValue();
                break;
            }
        }
        String webIndex = "topnav".equalsIgnoreCase(indexStyle) ? "index-topnav" : "index";
        return webIndex;
    }

    // 锁定屏幕
    @GetMapping("/lockscreen")
    public String lockscreen(ModelMap mmap)
    {
        mmap.put("user", getSysUser());
        ServletUtils.getSession().setAttribute(ShiroConstants.LOCK_SCREEN, true);
        return "lock";
    }

    // 解锁屏幕
    @PostMapping("/unlockscreen")
    @ResponseBody
    public AjaxResult unlockscreen(String password)
    {
        SysUser user = getSysUser();
        if (StringUtils.isNull(user))
        {
            return AjaxResult.error("服务器超时，请重新登录");
        }
        if (passwordService.matches(user, password))
        {
            ServletUtils.getSession().removeAttribute(ShiroConstants.LOCK_SCREEN);
            return AjaxResult.success();
        }
        return AjaxResult.error("密码不正确，请重新输入。");
    }

    // 切换主题
    @GetMapping("/system/switchSkin")
    public String switchSkin()
    {
        return "skin";
    }

    // 切换菜单
    @GetMapping("/system/menuStyle/{style}")
    public void menuStyle(@PathVariable String style, HttpServletResponse response)
    {
        CookieUtils.setCookie(response, "nav-style", style);
    }

    // 系统介绍
    @GetMapping("/system/main")
    public String main(  ModelMap mmap)
    {
        mmap.put("version", RuoYiConfig.getVersion());

        String sessionId = ShiroUtils.getSessionId();


        UserRelate userRelate = new UserRelate();
        userRelate.setUserId(getUserId());
        List<UserRelate> userRelates = userRelateService.selectUserRelateList(userRelate);
        //获取档案列表
//        List<Dangan>  danganList = danganService.selectDanganList(new Dangan());

        mmap.put("sessionId",sessionId);
        mmap.put("danganList",userRelates);

        //23年2月14日新增,加入档案信息
        if(!CollectionUtils.isEmpty(userRelates)) {
            for (UserRelate relate : userRelates) {
                Dangan dangan = danganService.selectDanganById(relate.getDanganId());
                if(!ObjectUtils.isEmpty(dangan)){
                    if(!StringUtils.isEmpty(dangan.getIconInfo())){
                        if(dangan.getIconInfo().contains("/upload")){
                            //期望给用户展示用的可直接访问的URL
                            String newStr = dangan.getIconInfo();
                            String[] ipPorts = ipPort.split(",");
                            //分ip+端口号 和 域名情况
                            if(ipPorts.length>=2){
                                //说明是由ip,端口组成的参数
                                newStr = "http://"+ipPorts[0]+":"+ipPorts[1]+"/iconShow"+newStr;
                            }else if(ipPorts.length==1){
                                //说明ip配置的是域名
                                newStr = "http://"+ipPorts[0]+"/iconShow"+newStr;
                            }
                            dangan.setIconInfo(newStr);
                        }
                    }else{
                        //说明档案图标未上传,那么使用默认图标
                        SysConfig configQuery = new SysConfig();
                        configQuery.setConfigKey("sys.main.defaultIcon");
                        SysConfig configEntity = configMapper.selectConfig(configQuery);
                        if(!ObjectUtils.isEmpty(configEntity)) {
                            String config = configEntity.getConfigValue();
                            if (!StringUtils.isEmpty(config)) {
                                //说明全局config表中已配置
                                //期望给用户展示用的可直接访问的URL
                                String newStr = config;
//                                String[] ipPorts = ipPort.split(",");
//                                //分ip+端口号 和 域名情况
//                                if (ipPorts.length >= 2) {
//                                    //说明是由ip,端口组成的参数
//                                    newStr = "http://" + ipPorts[0] + ":" + ipPorts[1] + "/iconShow" + newStr;
//                                } else if (ipPorts.length == 1) {
//                                    //说明ip配置的是域名
//                                    newStr = "http://" + ipPorts[0] + "/iconShow" + newStr;
//                                }
                                dangan.setIconInfo(newStr);
                            }
                        }
                    }
                    relate.setDangan(dangan);
                }
            }
        }
        return "main";
    }

    // content-main class
    public String contentMainClass(Boolean footer, Boolean tagsView)
    {
        if (!footer && !tagsView)
        {
            return "tagsview-footer-hide";
        }
        else if (!footer)
        {
            return "footer-hide";
        }
        else if (!tagsView)
        {
            return "tagsview-hide";
        }
        return StringUtils.EMPTY;
    }

    // 检查初始密码是否提醒修改
    public boolean initPasswordIsModify(Date pwdUpdateDate)
    {
        Integer initPasswordModify = Convert.toInt(configService.selectConfigByKey("sys.account.initPasswordModify"));
        return initPasswordModify != null && initPasswordModify == 1 && pwdUpdateDate == null;
    }

    // 检查密码是否过期
    public boolean passwordIsExpiration(Date pwdUpdateDate)
    {
        Integer passwordValidateDays = Convert.toInt(configService.selectConfigByKey("sys.account.passwordValidateDays"));
        if (passwordValidateDays != null && passwordValidateDays > 0)
        {
            if (StringUtils.isNull(pwdUpdateDate))
            {
                // 如果从未修改过初始密码，直接提醒过期
                return true;
            }
            Date nowDate = DateUtils.getNowDate();
            return DateUtils.differentDaysByMillisecond(nowDate, pwdUpdateDate) > passwordValidateDays;
        }
        return false;
    }
}
